@@ -1,52 +1,56 @@
-#!/bin/sh
+#!/usr/bin/env bash
 # really basic test driver
 # copy the rubber source, and the test case data to a temporary
 # directory, and run rubber on the file.
 
-SOURCE_DIR="$(cd ..; pwd)"
-tmpdir=tmp
-python=python3
-
 set -e                          # Stop at first failure.
 
-KEEP=false
 VERBOSE=
 while [ 1 -le $# ]; do
     case $1 in
-        --rmtmp)
-            rm -rf $tmpdir
-            shift
-            ;;
-        -k)
-            KEEP=true
-            shift
-            ;;
+		-d)
+			set -x
+			;;
         -v|-vv|-vvv)
             VERBOSE="$VERBOSE $1"
-            shift
+            ;;
+        --debchroot)
+            # Dependencies inside Debian.
+            apt install -y \
+                debhelper dh-python python3 texlive-latex-base asymptote \
+                biber cwebx imagemagick \
+                python3-prompt-toolkit python3-pygments r-cran-knitr \
+                texlive-bibtex-extra texlive-binaries texlive-extra-utils \
+                texlive-latex-extra texlive-latex-recommended \
+                texlive-metapost texlive-pictures transfig
+            # combine is not packaged for Debian.
+            touch combine/disable
             ;;
         *)
             break
     esac
+    shift
 done
 
+SOURCE_DIR="$(cd ..; pwd)"
+printf -v DATE '%(%Y%m%d)T' -1
+tmpdir=$(mktemp --tmpdir="/var/tmp" --directory "rubber-${DATE}-XXXXXX")
+readonly PYTHON="python3 -W error -X dev"
+
 echo "When a test fails, please remove the $tmpdir directory manually."
 
-# Copy source directory, because we must patch version.py and python
+# Copy source directory, because python
 # will attempt to write precompiled *.pyc sources.  For efficiency,
 # we share these temporary files among tests.
-mkdir $tmpdir
-cp -a "$SOURCE_DIR/src" $tmpdir/rubber
-sed "s%@version@%unreleased%;s%@moddir@%$SOURCE_DIR/data%" \
-    $tmpdir/rubber/version.py.in > $tmpdir/rubber/version.py
+cp -a "$SOURCE_DIR/rubber" $tmpdir/rubber
+# Also rename rubber to rubber.py to avoid a clash with rubber/.
 for exe in rubber rubber-info rubber-pipe; do
-    cp "$SOURCE_DIR/$exe" $tmpdir/$exe.py
-    alias $exe="$python ../$exe.py $VERBOSE"
+    cp "$SOURCE_DIR/bin/$exe" $tmpdir/$exe.py
 done
 
 for main; do
     case "$main" in
-        run.sh | shared | $tmpdir)
+        run.sh | shared)
             continue;;
     esac
 
@@ -80,14 +84,8 @@ for main; do
         . ./fragment
     else
         # default test code:  try to build two times, clean up.
-        echo "Running rubber $arguments $doc ..."
-
-        rubber $arguments "$doc"
-    fi
-
-    if $KEEP; then
-        echo "Keeping $tmpdir/$main."
-        exit 1
+        echo "Running $PYTHON ../rubber.py $VERBOSE $arguments $doc ..."
+        $PYTHON ../rubber.py $VERBOSE $arguments "$doc"
     fi
 
     ([ -r expected ] && cat expected ) | while read f; do
@@ -99,13 +97,13 @@ for main; do
 
     if ! [ -e fragment ]; then
         # default test code:  try to build two times, clean up.
-        rubber $arguments         "$doc"
-        rubber $arguments --clean "$doc"
+        $PYTHON ../rubber.py $VERBOSE $arguments         "$doc"
+        $PYTHON ../rubber.py $VERBOSE $arguments --clean "$doc"
     fi
 
     unset doc arguments
 
-    cd ../..
+    cd "${SOURCE_DIR}/tests"
 
     for before in $main/* shared/*; do
         after=$tmpdir/$main/${before##*/}
